InitializationStatus class

The status of the SDK initialization.

Constructors

InitializationStatus(Map<String, AdapterStatus> adapterStatuses)
Default constructor to create an InitializationStatus.

Properties

adapterStatuses → Map<String, AdapterStatus>
Initialization status of each known ad network, keyed by its adapter's class name.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited