FunctionalRewardedInterstitialAd class

Properties

no setter
hashCode → int
The hash code for this object.
no setterinherited
isReady → bool
no setter
loadAdError ↔ LoadAdError?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRewardedAdLoadCallback(RewardedInterstitialAdLoadCallback? userCallback) → RewardedInterstitialAdLoadCallback
dispose() → void
load({required String adUnitId, AdRequest? request, RewardedInterstitialAdLoadCallback? adLoadCallback}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show({bool? immersiveMode, FullScreenContentCallback<RewardedInterstitialAd>? fullScreenContentCallback, OnUserEarnedRewardCallback? onUserEarnedReward}) → Future<RewardItem>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

loadAndShow({required String adUnitId}) → Future<RewardItem>